package de.intevation.gnv.artifacts.fis.product;

import de.intevation.gnv.state.InputData;

import java.io.Serializable;

import java.util.Collection;

/**
 * This is the interface description of <code>Product</code>. Currently, there
 * are three methods defined:<br>
 * <ol>
 *  <li>getName(): retrieves the name of the <code>Product</code></li>
 *  <li>getParameter(): retrieves a collection of required parameters.</li>
 *  <li>getArtifactFactory(): retrieves the factory used to create this artifact.
 *  </li>
 * </ol>
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 */
public interface Product extends Serializable {

    /**
     *
     * @return The name of this product.
     */
    public String getName();

    /**
     *
     * @return All required parameters for parameterization.
     */
    public Collection<InputData> getParameter();

    /**
     *
     * @return The artifact factory used to create the current artifact.
     */
    public String getArtifactFactory();
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
